@@ -72,7 +72,6 @@ Catmandu::Fix::marc_copy - copy marc data in a structured way to a new field
     # Cut all 650 fields out of the MARC record into the subjects array
     marc_copy(650, subjects)
 
-
 =head1 DESCRIPTION
 
 Copy MARC data referred by MARC_TAG in a structured way to JSON path.
@@ -85,7 +84,30 @@ like tag, indicators and subfield codes into a nested data structure.
 
 =head2 marc_copy(MARC_PATH, JSON_PATH, [equals: REGEX])
 
-Copy this MARC fields referred by a MARC_PATH to a JSON_PATH.
+Copy this MARC fields referred by a MARC_PATH to a JSON_PATH. When an
+C<equals> value has been provided, then only the MARC_PATHs with a value
+equal to C<equals> will be copied to JSON_PATH. When the MARC_PATH points
+to a subfield, then the subfield value need to match C<equals>. When the
+MARC_PATH points multiple subfields, then a concatinated string value needs
+to match C<equals>:
+
+    Data:
+    100 $aMy$bField.
+
+    # copy only the 100 fields which have a $a subfield
+    marc_copy(100a,tmp)
+
+    # copy only the 100 fields with have a $a subfield matching 'My'
+    marc_copy(100a,tmp,equals:"My")
+
+    # copy only the 100 fields with have a concatinated string value 'MyField.'
+    # (equals is an regex, the period "." needs to be escaped "\.")
+    marc_copy(100,tmp,equals:"MyField\.")
+
+    # copy only the 100 fields which have a "." at the end
+    marc_copy(100,tmp,equals:"\.$")
+
+More examples:
 
     # Copy all the 300 fields
     marc_copy(300,tmp)
@@ -97,7 +119,7 @@ Copy this MARC fields referred by a MARC_PATH to a JSON_PATH.
     marc_copy(300c,tmp)
 
     # Copy all the 300 fields which have subfield c equal to 'ABC'
-    marc_copy(300c,tmp,equal:"^ABC")
+    marc_copy(300c,tmp,equals:"^ABC")
 
     The JSON_PATH C<tmp> will contain an array with one item per field that was copied.
     Each item is a hash containing the following fields:
@@ -105,7 +127,7 @@ Copy this MARC fields referred by a MARC_PATH to a JSON_PATH.
       tmp.*.tag        - The names of the MARC field
       tmp.*.ind1       - The value of the first indicator
       tmp.*.ind2       - The value of the second indicator
-      tmp.*.subfields  - An array of subfield item. Each subfield item is a
+      tmp.*.subfields  - An array of subfield items. Each subfield item is a
                          hash of the subfield code and subfield value
 
     E.g.
